@@ -2,7 +2,7 @@
 Emoji.
 
 pymdownx.emoji
-Emoji extension for emojione or Github's gemoji.
+Emoji extension for EmojiOne's, GitHub's, or Twemoji's gemoji.
 
 MIT license.
 
@@ -22,21 +22,24 @@ THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABI
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
-from __future__ import unicode_literals
 from markdown import Extension
-from markdown.inlinepatterns import Pattern
+from markdown.inlinepatterns import InlineProcessor
 from markdown import util as md_util
+import xml.etree.ElementTree as etree
+import inspect
+import copy
+import warnings
 from . import util
 
 RE_EMOJI = r'(:[+\-\w]+:)'
 SUPPORTED_INDEXES = ('emojione', 'gemoji', 'twemoji')
 UNICODE_VARIATION_SELECTOR_16 = 'fe0f'
-EMOJIONE_SVG_CDN = 'https://cdn.jsdelivr.net/emojione/assets/svg/'
-EMOJIONE_PNG_CDN = 'https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/'
-TWEMOJI_SVG_CDN = 'https://twemoji.maxcdn.com/2/svg/'
-TWEMOJI_PNG_CDN = 'https://twemoji.maxcdn.com/2/72x72/'
-GITHUB_UNICODE_CDN = 'https://assets-cdn.github.com/images/icons/emoji/unicode/'
-GITHUB_CDN = 'https://assets-cdn.github.com/images/icons/emoji/'
+EMOJIONE_SVG_CDN = 'https://cdnjs.cloudflare.com/ajax/libs/emojione/2.2.7/assets/svg/'
+EMOJIONE_PNG_CDN = 'https://cdnjs.cloudflare.com/ajax/libs/emojione/2.2.7/assets/png/'
+TWEMOJI_SVG_CDN = 'https://twemoji.maxcdn.com/v/latest/svg/'
+TWEMOJI_PNG_CDN = 'https://twemoji.maxcdn.com/v/latest/72x72/'
+GITHUB_UNICODE_CDN = 'https://github.githubassets.com/images/icons/emoji/unicode/'
+GITHUB_CDN = 'https://github.githubassets.com/images/icons/emoji/'
 NO_TITLE = 'none'
 LONG_TITLE = 'long'
 SHORT_TITLE = 'short'
@@ -45,9 +48,14 @@ UNICODE_ENTITY = 'html_entity'
 UNICODE_ALT = ('unicode', UNICODE_ENTITY)
 LEGACY_ARG_COUNT = 8
 
+MSG_INDEX_WARN = """Using emoji indexes with no arguments is now deprecated.
+Emoji indexes now take 2 arguments: 'options' and 'md'.
+Please update your custom index accordingly.
+"""
+
 
 def add_attriubtes(options, attributes):
-    """Add aditional attributes from options."""
+    """Add additional attributes from options."""
 
     attr = options.get('attributes', {})
     if attr:
@@ -55,32 +63,44 @@ def add_attriubtes(options, attributes):
             attributes[k] = v
 
 
-def emojione():
+def emojione(options, md):
     """The EmojiOne index."""
 
     from . import emoji1_db as emoji_map
-    return {"name": emoji_map.name, "emoji": emoji_map.emoji, "aliases": emoji_map.aliases}
+    return {
+        "name": emoji_map.name,
+        "emoji": copy.deepcopy(emoji_map.emoji),
+        "aliases": copy.deepcopy(emoji_map.aliases)
+    }
 
 
-def gemoji():
+def gemoji(options, md):
     """The Gemoji index."""
 
     from . import gemoji_db as emoji_map
-    return {"name": emoji_map.name, "emoji": emoji_map.emoji, "aliases": emoji_map.aliases}
+    return {
+        "name": emoji_map.name,
+        "emoji": copy.deepcopy(emoji_map.emoji),
+        "aliases": copy.deepcopy(emoji_map.aliases)
+    }
 
 
-def twemoji():
+def twemoji(options, md):
     """The Twemoji index."""
 
     from . import twemoji_db as emoji_map
-    return {"name": emoji_map.name, "emoji": emoji_map.emoji, "aliases": emoji_map.aliases}
+    return {
+        "name": emoji_map.name,
+        "emoji": copy.deepcopy(emoji_map.emoji),
+        "aliases": copy.deepcopy(emoji_map.aliases)
+    }
 
 
 ###################
 # Converters
 ###################
 def to_png(index, shortname, alias, uc, alt, title, category, options, md):
-    """Return png element."""
+    """Return PNG element."""
 
     if index == 'gemoji':
         def_image_path = GITHUB_UNICODE_CDN
@@ -95,7 +115,7 @@ def to_png(index, shortname, alias, uc, alt, title, category, options, md):
     is_unicode = uc is not None
     classes = options.get('classes', index)
 
-    # In genral we can use the alias, but github specific images don't have one for each alias.
+    # In general we can use the alias, but github specific images don't have one for each alias.
     # We can tell we have a github specific if there is no Unicode value.
     if is_unicode:
         image_path = options.get('image_path', def_image_path)
@@ -118,11 +138,11 @@ def to_png(index, shortname, alias, uc, alt, title, category, options, md):
 
     add_attriubtes(options, attributes)
 
-    return md_util.etree.Element("img", attributes)
+    return etree.Element("img", attributes)
 
 
 def to_svg(index, shortname, alias, uc, alt, title, category, options, md):
-    """Return svg element."""
+    """Return SVG element."""
 
     if index == 'twemoji':
         svg_path = TWEMOJI_SVG_CDN
@@ -143,11 +163,11 @@ def to_svg(index, shortname, alias, uc, alt, title, category, options, md):
 
     add_attriubtes(options, attributes)
 
-    return md_util.etree.Element("img", attributes)
+    return etree.Element("img", attributes)
 
 
 def to_png_sprite(index, shortname, alias, uc, alt, title, category, options, md):
-    """Return png sprite element."""
+    """Return PNG sprite element."""
 
     attributes = {
         "class": '%(class)s-%(size)s-%(category)s _%(unicode)s' % {
@@ -163,7 +183,7 @@ def to_png_sprite(index, shortname, alias, uc, alt, title, category, options, md
 
     add_attriubtes(options, attributes)
 
-    el = md_util.etree.Element("span", attributes)
+    el = etree.Element("span", attributes)
     el.text = md_util.AtomicString(alt)
 
     return el
@@ -171,68 +191,60 @@ def to_png_sprite(index, shortname, alias, uc, alt, title, category, options, md
 
 def to_svg_sprite(index, shortname, alias, uc, alt, title, category, options, md):
     """
-    Return svg sprite element.
+    Return SVG sprite element.
 
+    ```
     <svg class="%(classes)s"><description>%(alt)s</description>
     <use xlink:href="%(sprite)s#emoji-%(unicode)s"></use></svg>
+    ```
     """
 
     xlink_href = '%s#emoji-%s' % (
         options.get('image_path', './../assets/sprites/emojione.sprites.svg'), uc
     )
-    svg = md_util.etree.Element("svg", {"class": options.get('classes', index)})
-    desc = md_util.etree.SubElement(svg, 'description')
+    svg = etree.Element("svg", {"class": options.get('classes', index)})
+    desc = etree.SubElement(svg, 'description')
     desc.text = md_util.AtomicString(alt)
-    md_util.etree.SubElement(svg, 'use', {'xlink:href': xlink_href})
+    etree.SubElement(svg, 'use', {'xlink:href': xlink_href})
 
     return svg
 
 
-def to_awesome(index, shortname, alias, uc, alt, title, category, options, md):
-    """
-    Return "awesome style element for "font-awesome" format.
-
-    See: https://github.com/Ranks/emojione/tree/master/lib/emojione-awesome.
-    """
-
-    classes = '%s-%s' % (options.get('classes', 'e1a'), shortname[1:-1])
-    attributes = {"class": classes}
-    add_attriubtes(options, attributes)
-    return md_util.etree.Element("i", attributes)
-
-
 def to_alt(index, shortname, alias, uc, alt, title, category, options, md):
     """Return html entities."""
 
-    return md.htmlStash.store(alt, safe=True)
+    return md.htmlStash.store(alt)
 
 
 ###################
 # Classes
 ###################
-class EmojiPattern(Pattern):
-    """Return element of type `tag` with a text attribute of group(3) of a Pattern."""
+class EmojiPattern(InlineProcessor):
+    """Return element of type `tag` with a text attribute of group(2) of an `InlineProcessor`."""
 
     def __init__(self, pattern, config, md):
         """Initialize."""
 
+        InlineProcessor.__init__(self, pattern, md)
+
         title = config['title']
         alt = config['alt']
-
+        self.options = config['options']
         self._set_index(config["emoji_index"])
-        self.markdown = md
         self.unicode_alt = alt in UNICODE_ALT
         self.encoded_alt = alt == UNICODE_ENTITY
         self.remove_var_sel = config['remove_variation_selector']
         self.title = title if title in VALID_TITLE else NO_TITLE
         self.generator = config['emoji_generator']
-        self.options = config['options']
-        Pattern.__init__(self, pattern)
 
     def _set_index(self, index):
         """Set the index."""
 
-        self.emoji_index = index()
+        if len(inspect.getfullargspec(index).args):
+            self.emoji_index = index(self.options, self.md)
+        else:
+            warnings.warn(MSG_INDEX_WARN, util.PymdownxDeprecationWarning)
+            self.emoji_index = index()
 
     def _remove_variation_selector(self, value):
         """Remove variation selectors."""
@@ -260,8 +272,8 @@ class EmojiPattern(Pattern):
             'remove_variation_selector' option.
 
         If using gemoji, it is possible you will get no Unicode and no Unicode alt.  This occurs with emoji
-        like :octocat:.  :octocat: is not a real emoji and has no Unicode code points, but it is provided by
-        gememoji as an emoji anyways.
+        like `:octocat:`.  `:octocat:` is not a real emoji and has no Unicode code points, but it is provided by
+        gemoji as an emoji anyways.
         """
 
         uc = emoji.get('unicode')
@@ -300,10 +312,10 @@ class EmojiPattern(Pattern):
 
         return emoji.get('category')
 
-    def handleMatch(self, m):
-        """Hanlde emoji pattern matches."""
+    def handleMatch(self, m, data):
+        """Handle emoji pattern matches."""
 
-        el = m.group(2)
+        el = m.group(1)
 
         shortname = self.emoji_index['aliases'].get(el, el)
         alias = None if shortname == el else el
@@ -322,10 +334,10 @@ class EmojiPattern(Pattern):
                 title,
                 category,
                 self.options,
-                self.markdown
+                self.md
             )
 
-        return el
+        return el, m.start(0), m.end(0)
 
 
 class EmojiExtension(Extension):
@@ -366,15 +378,14 @@ class EmojiExtension(Extension):
         }
         super(EmojiExtension, self).__init__(*args, **kwargs)
 
-    def extendMarkdown(self, md, md_globals):
-        """Add support for emojis."""
+    def extendMarkdown(self, md):
+        """Add support for emoji."""
 
         config = self.getConfigs()
 
         util.escape_chars(md, [':'])
 
-        emj = EmojiPattern(RE_EMOJI, config, md)
-        md.inlinePatterns.add("emoji", emj, "<not_strong")
+        md.inlinePatterns.register(EmojiPattern(RE_EMOJI, config, md), "emoji", 75)
 
 
 ###################
