@@ -49,10 +49,10 @@ def _test(language, test_language=None):
     return test_language is None or test_language == '*' or language == test_language
 
 
-def _formatter(source, language, md, class_name="", fmt=None):
+def _formatter(src="", language="", md=None, class_name="", fmt=None):
     """Formatter wrapper."""
 
-    return fmt(source, language, class_name, md)
+    return fmt(src, language, class_name, md)
 
 
 class InlineHilitePattern(InlineProcessor):
@@ -126,8 +126,9 @@ class InlineHilitePattern(InlineProcessor):
             self.pygments_style = config['pygments_style']
             self.use_pygments = config['use_pygments']
             self.noclasses = config['noclasses']
+            self.language_prefix = config['language_prefix']
 
-    def highlight_code(self, src, language, classname=None, md=None):
+    def highlight_code(self, src='', language='', classname=None, md=None):
         """Syntax highlight the inline code block."""
 
         process_text = self.style_plain_text or language or self.guess_lang
@@ -138,7 +139,8 @@ class InlineHilitePattern(InlineProcessor):
                 pygments_style=self.pygments_style,
                 use_pygments=self.use_pygments,
                 noclasses=self.noclasses,
-                extend_pygments_lang=self.extend_pygments_lang
+                extend_pygments_lang=self.extend_pygments_lang,
+                language_prefix=self.language_prefix
             ).highlight(src, language, self.css_class, inline=True)
             el.text = self.md.htmlStash.store(el.text)
         else:
@@ -151,7 +153,11 @@ class InlineHilitePattern(InlineProcessor):
 
         for entry in reversed(self.formatters):
             if entry["test"](lang):
-                value = entry["formatter"](src, lang, self.md)
+                value = entry["formatter"](
+                    src=src,
+                    language=lang,
+                    md=self.md
+                )
                 if isinstance(value, str):
                     value = self.md.htmlStash.store(value)
                 return value
@@ -165,7 +171,10 @@ class InlineHilitePattern(InlineProcessor):
             lang = m.group('lang') if m.group('lang') else ''
             src = m.group('code').strip()
             self.get_settings()
-            return self.handle_code(lang, src), m.start(0), m.end(0)
+            try:
+                return self.handle_code(lang, src), m.start(0), m.end(0)
+            except Exception:
+                return m.group(0), None, None
 
 
 class InlineHiliteExtension(Extension):
